import defineProperty from '@babel/runtime/helpers/esm/defineProperty';
import clsx from 'clsx';
import { tw } from 'twind';

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

const variant = (args) => {
    return {
        variant: {
            type: args && args.type ? args.type : [String],
            default: args && args.default ? args.default : "",
            required: args && args.required ? args.required : false
        }
    };
};
const classAppend = (args) => {
    return {
        classAppend: {
            type: args && args.type ? args.type : [String, Array],
            default: args && args.default ? args.default : "",
            required: args && args.required ? args.required : false
        }
    };
};
const classRemove = (args) => {
    return {
        classRemove: {
            type: args && args.type ? args.type : [String, Array],
            default: args && args.default ? args.default : "",
            required: args && args.required ? args.required : false
        }
    };
};
const as = (args) => {
    return {
        as: {
            type: args && args.type ? args.type : [String, Object],
            default: args && args.default ? args.default : "div",
            required: args && args.required ? args.required : false
        }
    };
};
const status = (args) => {
    return {
        status: {
            type: args && args.type ? args.type : [String, Boolean],
            default: args && args.default ? args.default : false,
            required: args && args.required ? args.required : false,
            validator: args && args.validator ? args.validator : () => true
        }
    };
};
const size = (args) => {
    return {
        size: {
            type: args && args.type ? args.type : [String],
            default: args && args.default ? args.default : "",
            required: args && args.required ? args.required : false,
            validator: args && args.validator ? args.validator : () => true
        }
    };
};

// Classy
class Classy {
    constructor(starter) {
        if (starter) {
            this.value = Array.isArray(starter) ? starter : this.toArray(starter);
        }
        else {
            this.value = [];
        }
    }
    // Chains
    append(classes) {
        this.value = clsx(this.value, classes);
        return this;
    }
    remove(classes) {
        const classArray = typeof classes === "string" ? classes.split(" ") : classes;
        this.value = this.toArray(this.value).filter((className) => !classArray.includes(className));
        return this;
    }
    twind(enable = true) {
        if (enable) {
            this.value = tw `${this.value}`;
        }
        return this;
    }
    val(type) {
        if (type === "array") {
            return this.toArray(this.value);
        }
        return clsx(this.value);
    }
    // Helpers
    toArray(classes) {
        return typeof classes === "string" ? classes.split(" ") : classes;
    }
    toString(classes) {
        return Array.isArray(classes) ? classes.join(" ") : classes;
    }
}

const registerComponent = (instance, component) => {
    if (component) {
        instance.component(component.name || "", component);
    }
};

export { Classy as C, _objectSpread2 as _, classRemove as a, status as b, classAppend as c, as as d, registerComponent as r, size as s, variant as v };
